<?php

/**
 * Suppress "error - 0 - No summary was found for this file" on phpdoc generation
 *
 * @package WPDataProjects\Simple_Form
 */

namespace WPDataAccess\Manage_Media {

	use WPDataAccess\Data_Dictionary\WPDA_Dictionary_Lists;
	use WPDataAccess\Simple_Form\WPDA_Simple_Form;
	use WPDataAccess\Simple_Form\WPDA_Simple_Form_Item_Enum;

	/**
	 * Class WPDA_Manage_Media_Form
	 *
	 * Used to add and edit media items. Covered in a specific class mainly to handle tab navigation.
	 *
	 * @author  Peter Schulz
	 * @since   2.5.0
	 */
	class WPDA_Manage_Media_Form extends WPDA_Simple_Form {

		/**
		 * WPDA_Manage_Media_Form constructor.
		 *
		 * @param       $schema_name
		 * @param       $table_name
		 * @param       $wpda_list_columns
		 * @param array $args
		 */
		public function __construct( $schema_name, $table_name, &$wpda_list_columns, $args = [] ) {
			parent::__construct( $schema_name, $table_name, $wpda_list_columns, $args );

			$this->title    = __( 'Back', 'wp-data-access' );
			$this->subtitle = '';
		}

		/**
		 * Overwrite method to add tab.
		 *
		 * @param bool   $allow_save
		 * @param string $add_param
		 */
		public function show( $allow_save = true, $add_param = '' ) {
			parent::show( $allow_save, '&tab=managemedia' );

			?>
			<script language="JavaScript">
				function wpda_get_table_columns(selected_value='') {
					table_name = jQuery('[name="media_table_name"] :selected').val();
					var url = location.pathname + '?action=get_columns';
					var data = {table_name: table_name};
					jQuery.post(
						url,
						data,
						function (data) {
							jQuery('[name="media_column_name"]').find('option').remove();
							var jsonData = JSON.parse(data);
							for (i = 0; i < jsonData.length; i++) {
								if (jsonData[i]['column_name'] === selected_value) {
									jQuery('[name="media_column_name"]').append(
										jQuery("<option></option>")
										.attr("value", jsonData[i]['column_name'])
										.text(jsonData[i]['column_name'])
										.attr("selected", true)
									);
								} else {
									jQuery('[name="media_column_name"]').append(
										jQuery("<option></option>")
										.attr("value", jsonData[i]['column_name'])
										.text(jsonData[i]['column_name'])
									);
								}
							}
						}
					);
				}

				jQuery(document).ready(function () {
					jQuery('[name="media_table_name"]').on('click', function (event) {
						wpda_get_table_columns();
					});
				});
			</script>
			<?php
		}

		/**
		 * Overwrite method to add listboxes for tables and columns.
		 *
		 * @param bool $set_back_form_values
		 */
		public function prepare_items( $set_back_form_values = false ) {
			parent::prepare_items( $set_back_form_values );

			$i = 0;
			foreach ( $this->form_items as $item ) {
				if ( 'media_table_name' === $item->get_item_name() ) {
					$wpda_dictionary_lists = WPDA_Dictionary_Lists::get_tables();
					$lov                   = [];
					array_push( $lov, '' );
					foreach ( $wpda_dictionary_lists as $dictionary_list ) {
						array_push( $lov, $dictionary_list['table_name'] );
					}
					$item->set_enum( $lov );
					$item->set_label( 'Table Name' );
					$this->form_items[ $i ] = new WPDA_Simple_Form_Item_Enum( $item );
				}
				if ( 'media_column_name' === $item->get_item_name() ) {
					$lov = [];
					array_push( $lov, '' );
					$item->set_enum( $lov );
					$item->set_label( 'Column Name' );
					if ( $item->get_item_value() !== '' ) {
						$item_js =
							'jQuery(document).ready(function () { ' .
							'  wpda_get_table_columns("' . esc_attr( $item->get_item_value() ) . '"); ' .
							'});';
						$item->set_item_js( $item_js );
					}
					$this->form_items[ $i ] = new WPDA_Simple_Form_Item_Enum( $item );
				}
				if ( 'media_type' === $item->get_item_name() ) {
					$item->set_label( 'Media Type' );
				}
				if ( 'media_activated' === $item->get_item_name() ) {
					$item->set_label( 'Activated?' );
				}
				$i ++;
			}
		}

	}

}