<?php

/**
 * Suppress "error - 0 - No summary was found for this file" on phpdoc generation
 *
 * @package WPDataAccess\Settings
 */

namespace WPDataAccess\Manage_Media {

	use WPDataAccess\WPDA;

	/**
	 * Class WPDA_Manage_Media_Pool
	 *
	 * Gets all media defined columns. Usage:
	 *
	 * INIT: WPDA_Manage_Media_Pool::setup_pool();
	 * SELECT COLUMN: $media_type = WPDA_Manage_Media_Pool::get_column_media( $table_name, $column_name );
	 * or
	 * SELECT ALL COLUMNS: $media_types = WPDA_Manage_Media_Pool::get_pool();
	 *
	 * @author  Peter Schulz
	 * @since   2.5.0
	 */
	class WPDA_Manage_Media_Pool {

		/**
		 * Holds all defined media columns
		 *
		 * @var null|array
		 */
		protected static $media_columns = null;

		/**
		 * Set up media column pool
		 *
		 * Gets all defined media columns and stores them in a two dimensional named array
		 */
		public static function setup_pool() {
			if ( null === SELF::$media_columns ) {
				global $wpdb;

				$query = 'select * from ' . $wpdb->prefix . WPDA::get_option( WPDA::OPTION_WPDA_PREFIX ) . 'media ' .
				         'where media_activated = \'Yes\'';
				$media = $wpdb->get_results( $query, 'ARRAY_A' );

				foreach ( $media as $m ) {
					SELF::$media_columns[ $m['media_table_name'] ][ $m['media_column_name'] ] = $m[ 'media_type' ];
				}
			}
		}

		/**
		 * Returns pool (all media columns)
		 *
		 * @return array|null
		 */
		public static function get_pool() {
			return SELF::$media_columns;
		}

		/**
		 * Returns the media type for a specific database table/column
		 *
		 * Returns false if no media type is assigned to the database table/column
		 *
		 * @param $table_name
		 * @param $column_name
		 *
		 * @return bool|string
		 */
		public static function get_column_media( $table_name, $column_name ) {
			if ( isset( SELF::$media_columns[ $table_name ] [ $column_name ] ) ) {
				return SELF::$media_columns[ $table_name ] [ $column_name ];
			} else {
				return false;
			}
		}

	}

}